#
# spec file for package librepo
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2019 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without tests

# zchunk is only available in Leap 15.1 and newer
%if 0%{?sle_version} >= 150100 || 0%{?suse_version} >= 1550
%bcond_without zchunk
%endif

%define major 0
%define libname %{name}%{major}
%define devname %{name}-devel

Name:           librepo
Version:        1.9.6
Release:        lp151.1.1
Summary:        Repodata downloading library
License:        LGPL-2.0-or-later
Group:          Development/Libraries/C and C++

URL:            https://github.com/rpm-software-management/librepo
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz

# Patches proposed upstream
## Clean up target->curl_handle rather than target->handle (rh#1694411)
Patch0101:      librepo-PR148-clean-up-curl-target_handle.patch

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  gpgme-devel
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(glib-2.0) >= 2.26.0
BuildRequires:  pkgconfig(libcurl) >= 7.28.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(openssl)
%if %{with zchunk}
BuildRequires:  pkgconfig(zck) >= 0.9.11
%endif
BuildRequires:  python-rpm-macros

# prevent provides from nonstandard paths:
%global __provides_exclude ^(%{python3_sitearch}/.*\\.so)$

%description
A library providing C and Python (libcURL like) API for downloading repository
metadata.

%package -n %{libname}
Summary:        Repodata downloading library
Group:          System/Libraries

%description -n %{libname}
A library providing C and Python (libcURL like) API for downloading repository
metadata.

%package -n %{devname}
Summary:        Header files for the Repodata downloading library
Group:          Development/Libraries/C and C++
Requires:       %{libname}%{?_isa} = %{version}-%{release}

%description -n %{devname}
This package provides the development files for %{name}.

%package -n python3-librepo
Summary:        Python 3 bindings for the librepo library
Group:          Development/Libraries/Python
BuildRequires:  python3-devel
%if %{with tests}
BuildRequires:  python3-gpg
BuildRequires:  python3-Flask
BuildRequires:  python3-nose
%endif
BuildRequires:  python3-Sphinx
BuildRequires:  python3-xattr
Requires:       %{libname}%{?_isa} = %{version}-%{release}
# There is no more Python 2 subpackage
Obsoletes:      python2-librepo < 1.9.3

%description -n python3-librepo
This package provides the Python 3 bindings for the librepo library.

%prep
%autosetup -p1

%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo -DPYTHON_DESIRED:str=3 %{!?with_zchunk:-DWITH_ZCHUNK=OFF}
%make_build

%check
%if %{with tests}
pushd ./build
make ARGS="-V" test
make clean
popd
%endif

%install
pushd ./build
%make_install
popd

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%doc README.md
%license COPYING
%{_libdir}/librepo.so.%{major}

%files -n %{devname}
%{_libdir}/librepo.so
%{_libdir}/pkgconfig/librepo.pc
%{_includedir}/librepo/

%files -n python3-librepo
%{python3_sitearch}/librepo

%changelog
* Sun Mar 31 2019 Neal Gompa <ngompa13@gmail.com>
- Add patch to fix fetching zck-compressed repos (rh#1694411)
  * Patch: librepo-PR148-clean-up-curl-target_handle.patch
* Sun Mar 31 2019 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 1.9.6
  + Fix progress reporting with zchunk files
  + Reduce download delays by using still_running correctly
  + Improve error handling, cleanup
  + Simplified lr_perform()'s loop to prevent busy wait
  + Require libcurl >= 7.28.0
- Drop patch included in this release
  * Patch: PR138-Fix-progress-reporting-with-zchunk-files.patch
* Sun Feb  3 2019 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 1.9.3
  + Replace expat with libxml2
  + Support using python-gpg instead of pygpgme
  + Fix major performance regression with libcurl-7.61.1
  + Add zchunk support
- Drop patch for backported fix that is part of this release
  * Patch: 0001-stop-requiring-attr-xattr.patch
- Add patch proposed upstream to fix progress reporting for zck
  * Patch: PR138-Fix-progress-reporting-with-zchunk-files.patch
- Fix RPM group and description for Python 3 subpackage
- Drop Python 2 subpackage
* Thu Sep 13 2018 Jan Engelhardt <jengelh@inai.de>
- Fix RPM groups. Update descriptions so that librepo0
  (which is going to be installed most of the time) has something
  halfway useful.
* Thu Sep 13 2018 Neal Gompa <ngompa13@gmail.com>
- Backport fix from upstream to use glibc's xattr instead of libattr
  * Add patch: 0001-stop-requiring-attr-xattr.patch
- Use full author identities in changelog entries
* Thu Jan  4 2018 Neal Gompa <ngompa13@gmail.com>
- Upgrade to 1.8.1
  + Fix memory leaks in Python bindings (gh#rpm-software-management/librepo#83)
  + Fix HTTP header checking to work with proxies (gh#rpm-software-management/librepo#86)
  + Change connection and low-speed default timeouts to sync with DNF/Yum
  + Fix max download speed from repo (rh#1227921)
* Sun Aug 13 2017 Neal Gompa <ngompa13@gmail.com>
- Disable running unit tests by default because of random pygpgme failures
* Mon Feb 20 2017 Neal Gompa <ngompa13@gmail.com>
- Update to 1.7.20
* Mon Feb  1 2016 Neal Gompa <ngompa13@gmail.com>
- Use SUSE-specific groups and tags
* Mon Feb  1 2016 Neal Gompa <ngompa13@gmail.com>
- Initial packaging of librepo derived from Mageia packaging
